==> banshee-1-1.3.0.tar.bz2: banshee-1-1.3.0/src/Core/Banshee.Services/Banshee.Collection.Indexer/ICollectionIndexerService.cs <==
//
// ICollectionIndexer.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2008 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using NDesk.DBus;

using Banshee.ServiceStack;

namespace Banshee.Collection.Indexer
{
    [Interface ("org.bansheeproject.CollectionIndexer.Service")]
    public interface ICollectionIndexerService : IService, IDBusExportable
    {
        event Hyena.Action CollectionChanged;
        event Hyena.Action CleanupAndShutdown;
        
        void Hello ();
        void Shutdown ();
        ObjectPath CreateIndexer ();
        string [] GetAvailableExportFields ();
        bool HasCollectionCountChanged (int count);
        bool HasCollectionLastModifiedChanged (int time);
    }
}

==> banshee-1-1.3.1.tar.bz2: banshee-1-1.3.1/src/Core/Banshee.Services/Banshee.Collection.Indexer/ICollectionIndexerService.cs <==
//
// ICollectionIndexer.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2008 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using NDesk.DBus;

using Banshee.ServiceStack;

namespace Banshee.Collection.Indexer
{
    [Interface ("org.bansheeproject.CollectionIndexer.Service")]
    public interface ICollectionIndexerService : IService
    {
        event Hyena.Action CollectionChanged;
        event Hyena.Action CleanupAndShutdown;
        
        void Hello ();
        void Shutdown ();
        ObjectPath CreateIndexer ();
        string [] GetAvailableExportFields ();
        bool HasCollectionCountChanged (int count);
        bool HasCollectionLastModifiedChanged (int time);
    }
}
